==> vue-badge-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/badge/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import "@dftvue2-opentiny/vue-theme-mobile/badge/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["isDot", "isFixed", "isMini", "hidden", "max", "type", "value", "modelValue", "href", "target"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-badge"
  }, [_vm._t("default"), !_vm.hidden && (_vm.value > 0 || _vm.isDot) ? _c("div", {
    staticClass: "tiny-mobile-badge__content",
    class: [{
      "is-dot": _vm.isDot,
      "is-fixed": _vm.isFixed,
      "is-mini": _vm.isMini
    }, _vm.value < 10 ? "is-circle" : "", _vm.type ? "tiny-mobile-badge--" + _vm.type : ""]
  }, [!_vm.isDot ? _c("span", [_vm._t("content", function() {
    return [_c("a", {
      staticClass: "tiny-mobile-badge__link",
      attrs: {
        "href": _vm.state.href,
        "target": _vm.target,
        "rel": "noopener noreferrer"
      }
    }, [_vm._v(_vm._s(_vm.state.content))])];
  })], 2) : _vm._e()]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-badge-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/badge/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme-mobile/badge/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["isDot", "isFixed", "isMini", "hidden", "max", "type", "value", "modelValue", "href", "target"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-badge"
  }, [_vm._t("default"), !_vm.hidden && (_vm.value > 0 || _vm.isDot) ? _c("div", {
    staticClass: "tiny-mobile-badge__content",
    class: [{
      "is-dot": _vm.isDot,
      "is-fixed": _vm.isFixed,
      "is-mini": _vm.isMini
    }, _vm.value < 10 ? "is-circle" : "", _vm.type ? "tiny-mobile-badge--" + _vm.type : ""]
  }, [!_vm.isDot ? _c("span", [_vm._t("content", function() {
    return [_c("a", {
      staticClass: "tiny-mobile-badge__link",
      attrs: {
        "href": _vm.state.href,
        "target": _vm.target,
        "rel": "noopener noreferrer"
      }
    }, [_vm._v(_vm._s(_vm.state.content))])];
  })], 2) : _vm._e()]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
